@@ -3,17 +3,17 @@ from django.contrib import admin
 from django.core.exceptions import ObjectDoesNotExist
 from django.template.loader import render_to_string
 from django.urls.base import reverse
+from django.utils.html import format_html
 from django.utils.safestring import mark_safe
 from edc_action_item import action_fieldset_tuple
-from edc_action_item.modeladmin_mixins import ModelAdminActionItemMixin
+from edc_action_item.modeladmin_mixins import ActionItemModelAdminMixin
 from edc_constants.constants import DEAD
 from edc_model_admin import audit_fieldset_tuple
 from edc_model_admin.dashboard import ModelAdminSubjectDashboardMixin
 from edc_notification.utils import get_email_contacts
 
-from edc_adverse_event.get_ae_model import get_ae_model
-
 from ..forms import AeInitialForm
+from ..get_ae_model import get_ae_model
 from ..templatetags.edc_adverse_event_extras import (
     format_ae_description,
     select_description_template,
@@ -69,15 +69,17 @@ default_radio_fields = {
 class AeInitialModelAdminMixin(
     AdverseEventModelAdminMixin,
     ModelAdminSubjectDashboardMixin,
-    ModelAdminActionItemMixin,
+    ActionItemModelAdminMixin,
 ):
 
     form = AeInitialForm
 
     email_contact = get_email_contacts("ae_reports")
-    additional_instructions = mark_safe(
+    additional_instructions = format_html(  # nosec B308, B703
         "Complete the initial AE report and forward to the TMG. "
-        f'Email to <a href="mailto:{email_contact}">{email_contact}</a>'
+        'Email to <a href="mailto:{}">{}</a>',
+        mark_safe(email_contact),  # nosec B308, B703
+        mark_safe(email_contact),  # nosec B308, B703
     )
 
     fieldsets = (
@@ -94,35 +96,41 @@ class AeInitialModelAdminMixin(
 
     ordering = ["-tracking_identifier"]
 
-    list_display = [
-        "identifier",
-        "dashboard",
-        "description",
-        "follow_up_reports",
-        "user",
-    ]
-
-    list_filter = [
-        "ae_awareness_date",
-        "ae_grade",
-        "ae_classification",
-        "sae",
-        "sae_reason",
-        "susar",
-        "susar_reported",
-    ]
-
     search_fields = ["subject_identifier", "action_identifier", "tracking_identifier"]
 
+    def get_list_display(self, request) -> tuple:
+        list_display = super().get_list_display(request)
+        custom_fields = (
+            "identifier",
+            "dashboard",
+            "description",
+            "follow_up_reports",
+            "user",
+        )
+        return custom_fields + tuple(f for f in list_display if f not in custom_fields)
+
+    def get_list_filter(self, request) -> tuple:
+        list_filter = super().get_list_filter(request)
+        custom_fields = (
+            "ae_awareness_date",
+            "ae_grade",
+            "ae_classification",
+            "sae",
+            "sae_reason",
+            "susar",
+            "susar_reported",
+        )
+        return custom_fields + tuple(f for f in list_filter if f not in custom_fields)
+
     def if_sae_reason(self, obj):
         """Returns the SAE reason.
 
         If DEATH, adds link to the death report.
         """
         if obj.sae_reason.name == DEAD:
-            DeathReport = get_ae_model("deathreport")
+            death_report_cls = get_ae_model("deathreport")
             try:
-                death_report = DeathReport.objects.get(
+                death_report = death_report_cls.objects.get(
                     subject_identifier=obj.subject_identifier
                 )
             except ObjectDoesNotExist:
@@ -131,17 +139,20 @@ class AeInitialModelAdminMixin(
                 url_name = f"{settings.ADVERSE_EVENT_APP_LABEL}_deathreport"
                 namespace = self.admin_site.name
                 url = reverse(f"{namespace}:{url_name}_changelist")
-                link = (
-                    f'See report <a title="go to Death report"'
-                    f'href="{url}?q={death_report.subject_identifier}">'
-                    f"<span nowrap>{death_report.identifier}</span></a>"
+                link = format_html(  # nosec B308, B703
+                    'See report <a title="go to Death report"'
+                    'href="{}?q={}"><span nowrap>{}</span></a>',
+                    mark_safe(url),  # nosec B308, B703
+                    death_report.subject_identifier,
+                    death_report.identifier,
                 )
-            return mark_safe(f"{obj.sae_reason.name}.<BR>{link}.")
+            return format_html(f"{obj.sae_reason.name}.<BR>{link}.")
         return obj.get_sae_reason_display()
 
     if_sae_reason.short_description = "If SAE, reason"
 
-    def description(self, obj):
+    @staticmethod
+    def description(obj):
         """Returns a formatted comprehensive description of the SAE
         combining multiple fields.
         """
